# Polisseur

Machine de polissage de pièce (notamment imprimées 3D)

Très largement inspirée du projet "Affordable Rock Tumbler" (https://www.thingiverse.com/thing:935252) de J_T_3_D (https://www.thingiverse.com/J_T_3_D/about).

Presque entièrement redessinée pour que le cadre soit découpé à la fraisseuse à commande numérique et pour utiliser les pièces que j'avais en stock:
* structure en PEHD de 15mm d'épaisseur (à la place de l'impression 3D)
* moteur pas-à-pas NEMA 17 + électronique de contrôle (à la place du moteur à courant continu)
* de la tige fileté 8mm (axes de rotation) et 10mm (structure) à la place de 8mm partout (pas assez en stock).

## Améliorations par rapport au projet d'origine:
* l'électronique permet d'ajuster la vitesse et intégre un compte-à-rebour
* base en PEHD plus lourde, largement surdimensionnée, très stable
* le moteur peut être monté à droite ou à gauche
* la structure peut-être facilement usinée à la fraisseuse à commande numérique dans du plastique (PEHD ou autre), du bois ou du métal (aluminium). L'impression 3D de la structure reste possible aussi, mais consommera plus de plastique que la version originale

## Liste de matériel:
* structure:
  * plaque de plastique (PEHD par exemple) usinable, bois ou aluminium de 15mm d'épaisseur (possible d'ajuster à d'autres épaisseurs dans le fichier FreeCAD) pour y usiner les quatre pièces suivantes :
    * 2 ''spacer''
    * 1 ''frame'' droite
    * 1 ''frame'' gauche (symétrique à la droite)
  * 2 tiges filetées M10, longueur 255mm
  * 8 écrous M10 (idéal : 8, minimum 4)
  * 8 rondelles M10 (pas indispensable mais idéal = nombre d'écrous)
* parties mobiles:
  * Moteur pas-à-pas NEMA17
  * 4 vis M3 longueur 10 à 12mm (fixation du moteur sur la structure)
  * 1 vis M3 longueur 5-8mm (serrage de l'axe du m)
  * 1 tige filetée M8, longueur 240mm
  * 1 tige filetée M8, longueur 260mm
  * 18 écrous M8
  * 4 rondelles M8 (optionnelles)
  * 4 roulements à billes 608 (diamètre externe 22mm, interne 8mm, épaisseur 7mm)
  * 4 joints torique n°16 (19,8X27X3,6) pour les poulies
  * 4 poulies (impression 3D)
  * 1 grand engrenage (impression 3D)
  * 1 petit engrenage (impression 3D)
* électronique:
  * 1 afficheur avec microcontrôleur Sparkfun Serial 7-Segments Display (https://www.sparkfun.com/products/11441)
  * 1 pilote de moteur pas-à-pas Stepstick (https://reprap.org/wiki/StepStick)
  * 1 condensateur 100µF 16V (peut varier en fonction du pilote de moteur pas-à-pas)
  * 1 encodeur rotatif
  * 1 plaque perforée pour circuit électronique Adafruit Half-size perma-proto breadboard (https://www.adafruit.com/product/1609)
  * 1 connecteur 4 pins à souder adapté au moteur pas-à-pas (facultatif si on soude directement le cable du moteur sur le circuit)
  * 2 header mâles 8 broches pour brancher le driver (optionnels à la place on peut souder le driver directement sur le circuit, mais il sera plus difficile à changer en cas de panne)
  * quelques fils de couleurs variées pour connecter le tout
  * un connecteur d'alimentation type bornier-connecteur montable en façade, 3 broches (pour 5V, 12V et masse)
  * alimentation 5V (mini 500mA) et 12V (mini 2A)
  * 3 vis M3 longeur 5 à 8mm:
    * 1 vis pour fixer le circuit au boitier
    * 2 vis pour le connecteur d'alimentation (si vous utiliser le même que moi)
  * un boîtier (impression 3D)
* outillage:
  * fraisseuse numérique (remplacable par une imprimante 3D)
    * fraises pour le PEHD de 15mm :
        * 1 fraise 1 dent spirale diamètre 6mm profondeur de coupe 20 mm (16mm minimum)
        * 1 fraise 1 dent spirale diamètre 3mm profondeur de coupe 10 mm (pour les 4 oblongs de la visserie du moteur)
  * imprimante 3D
  * clés plates de 13 et de 17
  * clé à molette
  * jeux de clés Allen ou tournevis (suivant le type de vis M3)
  * fer à souder + accessoires

## Remarques

### Structure

On peut réaliser la structure dans d'autres matériaux (autre matière plastiques, bois, aluminium) ou d'autres épaisseurs. En cas de changement de matière ou d'épaisseur, il faut prendre en compte 

### Electronique
A propos de la partie électronique, la carte Sparkfun Serial 7-Segments Display intégre le microcontroleur Atmel ATMEGA 328, identique à un Arduino UNO R3. Cependant, il est nécessaire d'utiliser une carte intermédiaire pour la programmer. Personnellement, j'utilise une carte FTDI Friend d'Adafruit, mais il est possible de faire la même chose avec une carte Arduino UNO R3 dont le microcontroleur a été temporairement enlevé.

On peut donc tout à fait être remplacer par un Arduino UNO R3 ou équivalent avec un afficheur 7 segments 4 digits. Dans ce cas, le boitier n'est plus du tout adapté et il ne sert à rien de l'imprimer.

